import asyncio
import argparse
import json
import sys

from pymycity.cities import get_supported_cities
from pymycity.misc import cli_helper

REQUESTS_TIMEOUT = 4


def main():
    """Main function"""
    parser = argparse.ArgumentParser()
    parser.add_argument('-T', '--timeout',
                        default=REQUESTS_TIMEOUT, help='Request timeout')
    parser.add_argument('-a', '--show-all',
                        action="store_true", default=False,
                        help='Show all (not only the next dates)')
    parser.add_argument('-c', '--count',
                        type=int, default=None,
                        help='Show only N results')
    subparsers = parser.add_subparsers(title='City',
                                       description='Supported Cities',
                                       dest='city',
                                       help='City name')
    # Load all cities
    cities = get_supported_cities(subparsers)
    # Parse args
    cli_args = parser.parse_args()
    if cli_args.city is None:
        cli_helper(parser, cities)
        return
    # Get selected city
    mycity = cities[cli_args.city]
    # Run command
    if cli_args.command is None:
        mycity.parser.print_help()
    else:
        loop = asyncio.get_event_loop()
        city_func = getattr(mycity, "cli_" + cli_args.command)
        fut = asyncio.wait([city_func(cli_args)])
        try:
            loop.run_until_complete(fut)
        except Exception:
            mycity.close_session()
            return
        mycity.close_session()


if __name__ == '__main__':
    sys.exit(main())



from datetime import date

class Item():

    def __init__(self, title, start, end=None, location=None, url=None, all_day=False, description=None, metadata=None):
        self.title = title
        self.start = start
        self.end = end
        self.location = location
        self.url = url
        self._all_day = all_day
        self.description = description
        self.metadata = metadata
        if self.metadata is None:
            self.metadata = {}

    @property
    def all_day(self):
        if isinstance(self.start, date) and isinstance(self.end, date):
            return True
        return self._all_day



import pprint


def cli_helper(parser, cities):
    help_data = {"Cities": {}}
    for city_name in sorted(cities):
        help_data["Cities"][city_name] = {}
        for command in cities[city_name].commands:
            command_help = command.parser.format_help().replace(command.parser.format_usage(), "").strip("\n")
            #command_help = command.parser.format_help().strip("\n")
            help_data["Cities"][city_name][command.name] = command.help

    messages = []
    for title, cities_data in help_data.items():
        msg = "{}:".format(title)
        messages.append(msg)
        for city_name, city_commands in cities_data.items():
            msg = "    * {}:".format(city_name)
            messages.append(msg)
            for command_name, command_help in city_commands.items():
                msg = "        + {}:".format(command_name)
                messages.append(msg)
                messages.append("            - {}".format(command_help))
    parser.print_usage()
    print("\n")
    print("\n".join(messages))



from setuptools import setup
  
install_requires = list(val.strip() for val in open('requirements.txt'))
tests_require = list(val.strip() for val in open('test_requirements.txt'))

long_desc = open('README.rst').read()

setup(name='pymycity',
      version='0.2.2',
      description='Get your city live information',
      long_description=long_desc,
      author='Thibault Cohen',

      author_email='titilambert@gmail.com',
      url='http://github.com/titilambert/pymycity',
      packages=['pymycity'],
      entry_points={
          'console_scripts': [
              'pymycity = pymycity.__main__:main'
          ]
      },
      install_requires=install_requires,
      tests_require=tests_require,
      classifiers=[
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
      ],
)
